Cursor

Struct Cursor 

pub(crate) struct Cursor<'a, T: EncodingType> {
    pos: usize,
    source: &'a [T::CodeUnit],
}
Cursor is a small cursor implementation for parsing Iso8601 grammar.

Fields

pos: usizesource: &'a [T::CodeUnit]

Implementations

Source

impl<'a, T: EncodingType> Cursor<'a, T>

pub fn new(source: &'a [T::CodeUnit]) -> Self

Create a new cursor from a source UTF8 string.

pub(crate) fn slice( &self, start: usize, end: usize, ) -> Option<&'a [T::CodeUnit]>

Returns a string value from a slice of the cursor.

pub(crate) const fn pos(&self) -> usize

Get current position

pub(crate) fn set_position(&mut self, pos: usize)

Get current position

pub(crate) fn peek(&self) -> ParserResult<Option<u8>>

Peek the value at next position (current + 1).

pub(crate) fn current(&self) -> ParserResult<Option<u8>>

Returns current position in source as char.

pub(crate) fn peek_n(&self, n: usize) -> ParserResult<Option<u8>>

Peeks the value at n as a char.

pub(crate) fn check<F>(&self, f: F) -> ParserResult<Option<bool>>
where F: FnOnce(u8) -> bool,

Runs the provided check on the current position.

pub(crate) fn check_or<F>(&self, default: bool, f: F) -> ParserResult<bool>
where F: FnOnce(u8) -> bool,

Runs the provided check on current position returns the default value if None.

pub(crate) fn next(&mut self) -> ParserResult<Option<u8>>

Returns Cursor’s current char and advances to the next position.

pub(crate) fn next_digit(&mut self) -> ParserResult<Option<u8>>

Returns the next value as a digit

Errors
pub(crate) fn next_or(&mut self, err: ParseError) -> ParserResult<u8>

A utility next method that returns an ParseError::AbruptEnd error if invalid.

pub(crate) fn advance_n(&mut self, n: usize)

Advances the cursor’s position by n code points.

pub(crate) fn advance(&mut self)

pub(crate) fn advance_if(&mut self, condition: bool)

Utility function to advance when a condition is true

pub(crate) fn close(&mut self) -> ParserResult<()>

Closes the current cursor by checking if all contents have been consumed. If not, returns an error for invalid syntax.